/* *******************************************************************************
 *  Copyright (C) 2014-2021 Mehmet Gunce Akkoyun Can not be copied and/or
 *	distributed without the express permission of Mehmet Gunce Akkoyun
 *	This library is a combined book of enviroment sensor library.
 *
 *	Library				: B902AA Device Library
 *	Code Developer		: Mehmet Gunce Akkoyun (akkoyun@me.com)
 *	Revision			: 1.0.2
 *	Relase				: 19.08.2021
 *
 *********************************************************************************/

#ifndef __B902AA__
#define __B902AA__

// Define Arduino Library
#ifndef __Arduino__
#include <Arduino.h>
#endif

// Define Wire Library
#ifndef __Wire__
#include <Wire.h>
#endif

// Define Battery Library
#ifndef __Battery__
#include <Battery.h>
#endif

class STF_B902AA
{
public:

	// ************************************************************
	// Public Variables
	// ************************************************************

	// ************************************************************
	// Public Enum Definations
	// ************************************************************

	enum LED_Color_ {
		RED,				// Red
		GREEN,				// Green
		BLUE				// Blue
	};
	enum LED_Choice_ {
		LED1,				// LED 1
		LED2				// LED 2
	};

	// ************************************************************
	// Public Struct Definations
	// ************************************************************

	// Diagnostic Variables
	struct Struct_Diag {

		//------------------------------------------------------------------
		bool		Mux;				// Multiplexer
		bool		Gauge;				// Battery Gauge
		bool		Temperature;		// Temperature Sensor
		bool 		INTLCD;				// LCD
		bool 		EXTLCD;				// LCD
		//------------------------------------------------------------------

	}; Struct_Diag Diagnostic {
		
		//------------------------------------------------------------------
		false,
		false,
		false,
		false,
		false
		//------------------------------------------------------------------

	};
	
	// Battery Variables
	struct Battery_Gauge {

		//------------------------------------------------------------------
		float		Instant_Voltage;
		float		Capacity;
		float		Full_Capacity;
		float		Average_Current;
		float		StateOfCharge;
		float		Temperature;
		float		Cycle;
		//------------------------------------------------------------------

	}; Battery_Gauge Battery {
		
		//------------------------------------------------------------------
		0,
		0,
		0,
		0,
		0,
		0,
		0
		//------------------------------------------------------------------

	};

	// ************************************************************
	// Public Functions
	// ************************************************************
		
	// Hardware Functions
	void HardwareDiagnostic(void);
	
	// I2C Functions
	bool Multiplexer(uint8_t _Channel);

	// LED Functions
	void LED(uint8_t _LED, uint8_t _Color, bool _State);
	void LED_Blink(uint8_t _LED, uint8_t _Color, uint8_t _Blink, int _Interval);

	// Battery Functions
	void Gauge_Initialize(void);
	
private:

	// ************************************************************
	// Private Variables
	// ************************************************************

	uint8_t _Multiplexer_Current_Channel = 0;

	// ************************************************************
	// Private Enum Definations
	// ************************************************************

	enum _I2C_Definations {
		_OFF_,				// 0
		_TEMPERATURE_,		// 1
		_INTLCD_,			// 2
		_EXTLCD_,			// 3
		_EXTI2C_			// 4
	};

	// ************************************************************
	// Private Functions
	// ************************************************************

};

extern STF_B902AA B902AA;

#endif /* defined(__B902AA__) */
